Crate stripe_fraud

Crate stripe_fraud 

This crate provides Rust bindings to the Stripe HTTP API, specifically for requests mentioned in the Fraud section of the Stripe API docs

Modules

radar_early_fraud_warning
radar_payment_evaluation
radar_value_list
radar_value_list_item
review

Structs

DeletedRadarValueList
DeletedRadarValueListBuilder
DeletedRadarValueListItem
DeletedRadarValueListItemBuilder
InsightsResourcesPaymentEvaluationAddress
Address data.
InsightsResourcesPaymentEvaluationAddressBuilder
InsightsResourcesPaymentEvaluationBillingDetails
Billing details attached to this payment evaluation.
InsightsResourcesPaymentEvaluationBillingDetailsBuilder
InsightsResourcesPaymentEvaluationClientDeviceMetadata
Client device metadata attached to this payment evaluation.
InsightsResourcesPaymentEvaluationClientDeviceMetadataBuilder
InsightsResourcesPaymentEvaluationCustomerDetails
Customer details attached to this payment evaluation.
InsightsResourcesPaymentEvaluationCustomerDetailsBuilder
InsightsResourcesPaymentEvaluationDisputeOpened
Dispute opened event details attached to this payment evaluation.
InsightsResourcesPaymentEvaluationDisputeOpenedBuilder
InsightsResourcesPaymentEvaluationEarlyFraudWarningReceived
Early Fraud Warning Received event details attached to this payment evaluation.
InsightsResourcesPaymentEvaluationEarlyFraudWarningReceivedBuilder
InsightsResourcesPaymentEvaluationEvent
Event reported for this payment evaluation.
InsightsResourcesPaymentEvaluationEventBuilder
InsightsResourcesPaymentEvaluationMerchantBlocked
Details of a merchant_blocked outcome attached to this payment evaluation.
InsightsResourcesPaymentEvaluationMerchantBlockedBuilder
InsightsResourcesPaymentEvaluationMoneyMovementCard
Money Movement card details attached to this payment.
InsightsResourcesPaymentEvaluationMoneyMovementCardBuilder
InsightsResourcesPaymentEvaluationMoneyMovementDetails
Money Movement details attached to this payment.
InsightsResourcesPaymentEvaluationMoneyMovementDetailsBuilder
InsightsResourcesPaymentEvaluationOutcome
Outcome details for this payment evaluation.
InsightsResourcesPaymentEvaluationOutcomeBuilder
InsightsResourcesPaymentEvaluationPaymentDetails
Payment details attached to this payment evaluation.
InsightsResourcesPaymentEvaluationPaymentDetailsBuilder
InsightsResourcesPaymentEvaluationPaymentMethodDetails
Payment method details attached to this payment evaluation.
InsightsResourcesPaymentEvaluationPaymentMethodDetailsBuilder
InsightsResourcesPaymentEvaluationRefunded
Refunded Event details attached to this payment evaluation.
InsightsResourcesPaymentEvaluationRefundedBuilder
InsightsResourcesPaymentEvaluationRejected
Details of an rejected outcome attached to this payment evaluation.
InsightsResourcesPaymentEvaluationRejectedBuilder
InsightsResourcesPaymentEvaluationRejectedCard
Details of an rejected card outcome attached to this payment evaluation.
InsightsResourcesPaymentEvaluationRejectedCardBuilder
InsightsResourcesPaymentEvaluationShipping
Shipping details attached to this payment.
InsightsResourcesPaymentEvaluationShippingBuilder
InsightsResourcesPaymentEvaluationSignalV2
A payment evaluation signal with evaluated_at, risk_level, and score fields.
InsightsResourcesPaymentEvaluationSignalV2Builder
InsightsResourcesPaymentEvaluationSignals
Collection of signals for this payment evaluation.
InsightsResourcesPaymentEvaluationSignalsBuilder
InsightsResourcesPaymentEvaluationSucceeded
Details of a succeeded outcome attached to this payment evaluation.
InsightsResourcesPaymentEvaluationSucceededBuilder
InsightsResourcesPaymentEvaluationSucceededCard
Details of an succeeded card outcome attached to this payment evaluation.
InsightsResourcesPaymentEvaluationSucceededCardBuilder
InsightsResourcesPaymentEvaluationUserInterventionRaised
User intervention raised event details attached to this payment evaluation
InsightsResourcesPaymentEvaluationUserInterventionRaisedBuilder
InsightsResourcesPaymentEvaluationUserInterventionRaisedCustom
User intervention raised custom event details attached to this payment evaluation
InsightsResourcesPaymentEvaluationUserInterventionRaisedCustomBuilder
InsightsResourcesPaymentEvaluationUserInterventionResolved
User Intervention Resolved Event details attached to this payment evaluation
InsightsResourcesPaymentEvaluationUserInterventionResolvedBuilder
RadarEarlyFraudWarning
An early fraud warning indicates that the card issuer has notified us that a charge may be fraudulent.
RadarEarlyFraudWarningId
RadarPaymentEvaluation
Payment Evaluations represent the risk lifecycle of an externally processed payment. It includes the Radar risk score from Stripe, payment outcome taken by the merchant or processor, and any post transaction events, such as refunds or disputes. See the Radar API guide for integration steps.
RadarPaymentEvaluationId
RadarReviewResourceLocation
RadarReviewResourceSession
RadarValueList
Value lists allow you to group values together which can then be referenced in rules.
RadarValueListId
RadarValueListItem
Value list items allow you to add specific values to a given Radar value list, which can then be used in rules.
RadarValueListItemId
Review
Reviews can be used to supplement automated fraud detection with human expertise.
ReviewId
Rule
RuleId

Enums

InsightsResourcesPaymentEvaluationDisputeOpenedReason
Reason given by cardholder for dispute.
InsightsResourcesPaymentEvaluationEarlyFraudWarningReceivedFraudType
The type of fraud labeled by the issuer.
InsightsResourcesPaymentEvaluationEventType
Indicates the type of event attached to the payment evaluation.
InsightsResourcesPaymentEvaluationMerchantBlockedReason
The reason the payment was blocked by the merchant.
InsightsResourcesPaymentEvaluationMoneyMovementCardCustomerPresence
Describes the presence of the customer during the payment.
InsightsResourcesPaymentEvaluationMoneyMovementCardPaymentType
Describes the type of payment.
InsightsResourcesPaymentEvaluationMoneyMovementDetailsMoneyMovementType
Describes the type of money movement. Currently only card is supported.
InsightsResourcesPaymentEvaluationOutcomeType
Indicates the outcome of the payment evaluation.
InsightsResourcesPaymentEvaluationRefundedReason
Indicates the reason for the refund.
InsightsResourcesPaymentEvaluationRejectedCardAddressLine1Check
Result of the address line 1 check.
InsightsResourcesPaymentEvaluationRejectedCardAddressPostalCodeCheck
Indicates whether the cardholder provided a postal code and if it matched the cardholder’s billing address.
InsightsResourcesPaymentEvaluationRejectedCardCvcCheck
Result of the CVC check.
InsightsResourcesPaymentEvaluationRejectedCardReason
Card issuer’s reason for the network decline.
InsightsResourcesPaymentEvaluationSignalV2RiskLevel
Risk level of this signal, based on the score.
InsightsResourcesPaymentEvaluationSucceededCardAddressLine1Check
Result of the address line 1 check.
InsightsResourcesPaymentEvaluationSucceededCardAddressPostalCodeCheck
Indicates whether the cardholder provided a postal code and if it matched the cardholder’s billing address.
InsightsResourcesPaymentEvaluationSucceededCardCvcCheck
Result of the CVC check.
InsightsResourcesPaymentEvaluationUserInterventionRaisedType
Type of user intervention raised.
InsightsResourcesPaymentEvaluationUserInterventionResolvedOutcome
Result of the intervention if it has been completed.
RadarPaymentEvaluationRecommendedAction
Recommended action based on the score of the fraudulent_payment signal. Possible values are block and continue.
RadarValueListItemType
ReviewClosedReason
The reason the review was closed, or null if it has not yet been closed. One of approved, refunded, refunded_as_fraud, disputed, redacted, canceled, payment_never_settled, or acknowledged.
ReviewOpenedReason
The reason the review was opened. One of rule or manual.